[telepathy-glib/master] account-manager: rename _get_accounts to _get_valid_accounts

Jonny Lamb jonny.lamb at collabora.co.uk
Mon Sep 28 02:42:48 PDT 2009


Signed-off-by: Jonny Lamb <jonny.lamb at collabora.co.uk>
---
 docs/reference/telepathy-glib-sections.txt |    2 +-
 telepathy-glib/account-manager.c           |   16 ++++++++--------
 telepathy-glib/account-manager.h           |    2 +-
 3 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/docs/reference/telepathy-glib-sections.txt b/docs/reference/telepathy-glib-sections.txt
index 3356fe0..6cf361c 100644
--- a/docs/reference/telepathy-glib-sections.txt
+++ b/docs/reference/telepathy-glib-sections.txt
@@ -3069,7 +3069,7 @@ tp_account_manager_dup
 tp_account_manager_create_account_async
 tp_account_manager_create_account_finish
 tp_account_manager_ensure_account
-tp_account_manager_get_accounts
+tp_account_manager_get_valid_accounts
 tp_account_manager_get_most_available_presence
 tp_account_manager_set_all_requested_presences
 <SUBSECTION>
diff --git a/telepathy-glib/account-manager.h b/telepathy-glib/account-manager.h
index 51099fb..9ef47dd 100644
--- a/telepathy-glib/account-manager.h
+++ b/telepathy-glib/account-manager.h
@@ -78,7 +78,7 @@ void tp_account_manager_init_known_interfaces (void);
 TpAccount *tp_account_manager_ensure_account (TpAccountManager *manager,
     const gchar *path);
 
-GList *tp_account_manager_get_accounts (TpAccountManager *manager);
+GList *tp_account_manager_get_valid_accounts (TpAccountManager *manager);
 
 void tp_account_manager_set_all_requested_presences (TpAccountManager *manager,
     TpConnectionPresenceType type, const gchar *status, const gchar *message);
diff --git a/telepathy-glib/account-manager.c b/telepathy-glib/account-manager.c
index 5dd5520..21f4424 100644
--- a/telepathy-glib/account-manager.c
+++ b/telepathy-glib/account-manager.c
@@ -994,33 +994,33 @@ tp_account_manager_ensure_account (TpAccountManager *manager,
 }
 
 /**
- * tp_account_manager_get_accounts:
+ * tp_account_manager_get_valid_accounts:
  * @manager: a #TpAccountManager
  *
  * Returns a newly allocated #GList of accounts in @manager. The list must be
  * freed with g_list_free() after used. None of the accounts in the returned
  * list are guaranteed to be ready.
  *
  * Note that the #TpAccount<!-- -->s in the returned #GList are not reffed
  * before returning from this function. One could ref every item in the list
  * like the following example:
  * |[
  * GList *accounts;
- * account = tp_account_manager_get_accounts (manager);
+ * account = tp_account_manager_get_valid_accounts (manager);
  * g_list_foreach (accounts, (GFunc) g_object_ref, NULL);
  * ]|
  *
  * The list of accounts on @manager is not guaranteed to have been retrieved
  * until %TP_ACCOUNT_MANAGER_FEATURE_CORE is prepared
  * (tp_account_manager_prepare_async() has returned). Until this feature has
  * been prepared, an empty list (%NULL) will be returned.
  *
  * Returns: a newly allocated #GList of accounts in @manager
  *
  * Since: 0.7.UNRELEASED
  */
 GList *
-tp_account_manager_get_accounts (TpAccountManager *manager)
+tp_account_manager_get_valid_accounts (TpAccountManager *manager)
 {
   TpAccountManagerPrivate *priv;
   GList *ret;
@@ -994,33 +994,33 @@ tp_account_manager_ensure_account (TpAccountManager *manager,
  * @manager: a #TpAccountManager
  *
- * Returns a newly allocated #GList of accounts in @manager. The list must be
- * freed with g_list_free() after used. None of the accounts in the returned
- * list are guaranteed to be ready.
+ * Returns a newly allocated #GList of valid accounts in @manager. The list
+ * must be freed with g_list_free() after used. None of the accounts in the
+ * returned list are guaranteed to be ready.
  *
  * Note that the #TpAccount<!-- -->s in the returned #GList are not reffed
@@ -994,33 +994,33 @@ tp_account_manager_ensure_account (TpAccountManager *manager,
  * ]|
  *
- * The list of accounts on @manager is not guaranteed to have been retrieved
+ * The list of valid accounts returned is not guaranteed to have been retrieved
  * until %TP_ACCOUNT_MANAGER_FEATURE_CORE is prepared
  * (tp_account_manager_prepare_async() has returned). Until this feature has
@@ -994,33 +994,33 @@ tp_account_manager_ensure_account (TpAccountManager *manager,
  * been prepared, an empty list (%NULL) will be returned.
  *
- * Returns: a newly allocated #GList of accounts in @manager
+ * Returns: a newly allocated #GList of valid accounts in @manager
  *
  * Since: 0.7.UNRELEASED
-- 
1.5.6.5




More information about the telepathy-commits mailing list